summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authornoah <noah@656d521f-e311-0410-88e0-e7920216d269>2002-10-16 19:02:56 +0000
committernoah <noah@656d521f-e311-0410-88e0-e7920216d269>2002-10-16 19:02:56 +0000
commit2a82b0c164ee2e26441316817c87badf508a76dd (patch)
tree14e9e9d6e8f6101e4e1dafee4bc6b8fd049b3e69
parent928a421ff9a5820f52f599e9ab77229d940bde94 (diff)
downloadpexpect-2a82b0c164ee2e26441316817c87badf508a76dd.tar.gz
Apparently RedHat 8.0 has more than 1000 pty devices. I bumped this to 10000.
Now the test passes (by failing to create more than 10000 pty devices). git-svn-id: http://pexpect.svn.sourceforge.net/svnroot/pexpect/trunk@105 656d521f-e311-0410-88e0-e7920216d269
-rwxr-xr-xpexpect/tests/test_run_out_of_pty.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/pexpect/tests/test_run_out_of_pty.py b/pexpect/tests/test_run_out_of_pty.py
index 18eac41..5499e75 100755
--- a/pexpect/tests/test_run_out_of_pty.py
+++ b/pexpect/tests/test_run_out_of_pty.py
@@ -8,10 +8,10 @@ class ExpectTestCase(unittest.TestCase):
#def runTest (self):
def test_run_out (self):
"""This assumes that the tested platform has less than 1000 pty devices.
"""
plist=[]
- for count in range (0,1000):
+ for count in range (0,10000):
try:
plist.append (pexpect.spawn('ls -l'))
except pexpect.ExceptionPexpect, e:
@@ -8,10 +8,10 @@ class ExpectTestCase(unittest.TestCase):
#def runTest (self):
def test_run_out (self):
- """This assumes that the tested platform has less than 1000 pty devices.
+ """This assumes that the tested platform has less than 10000 pty devices.
"""
plist=[]